﻿using BPA.Common.Infrastructure.BizLogs;
using BPA.Common.Infrastructure.Queue;
using BPA.Component.RabbitMQClient.Extensions;
using BPA.Component.RabbitMQClient.Provider;
using BPA.SaaS.Annex.Api.Model;
using Microsoft.Extensions.DependencyInjection;

namespace BPA.SaaS.Annex.Api.Bootstrap
{
    /// <summary>
    /// RabbitMQ配置 
    /// </summary>
    public static class SetupRabbitMqConfig
    {
        /// <summary>
        /// 使用消息队列
        /// </summary>
        /// <param name="services"></param>
        /// <returns></returns>
        public static IServiceCollection AddRabbitMQ(this IServiceCollection services)
        {
            //注入 RabbitMQProvider
            services.AddRabbitMQProvider(sp => sp.GetService<AnnexApiConfig>()?.RabbitMqConfig);
            //注入 业务日志 生产者
            services.AddRabbitMQProducer<BizLogProducer, BaseBizLogMsgBody>();

            return services;
        }

        /// <summary>
        /// 预热消息队列
        /// </summary>
        /// <param name="serviceProvider"></param>
        /// <returns></returns>
        public static IServiceProvider PreHeatRunRabbitMQ(this IServiceProvider serviceProvider)
        {
            var rabbitMqProvider = serviceProvider.UseRabbitMQProvider<RabbitMQProvider>();
            
            var exchangeConfig = rabbitMqProvider.BuildExchangeConfig(MqNameConfig.BizLogExchange);
            exchangeConfig.UseExchange();
            exchangeConfig.UseProducer<BaseBizLogMsgBody, BizLogProducer>();
            
            return serviceProvider;
        }
    }
}