﻿using BPA.Component.DTOCommon.BaseDTOs;
using BPA.SaaS.Annex.Api.DTO;

namespace BPA.SaaS.Annex.Api.IService
{
    /// <summary>
    /// 附件服务
    /// </summary>
    public interface IAnnexService
    {
        /// <summary>
        /// 获取附件列表
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        BaseResult<List<AnnexInfoDTO>> GetList(GetListReq req);

        /// <summary>
        /// 删除指定业务数据的所有附件信息
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        BaseResult<bool> RemoveAnnexByBusinessId(RemoveAnnexByBusinessIdReq req);

        /// <summary>
        /// 删除指定的附件信息
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        BaseResult<bool> RemoveAnnexByAnnexId(RemoveAnnexByAnnexIdReq req);

        /// <summary>
        /// 上传附件
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        BaseResult<bool> Upload(UploadAnnexReq req);

        /// <summary>
        /// 获取附件详情
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        BaseResult<AnnexInfoDTO> GetAnnexInfo(GetAnnexInfoReq req);

        /// <summary>
        /// 清理无效的文件 | 定时任务调用
        /// </summary>
        /// <returns></returns>
        BaseResult<bool> ClearTemporaryFile();

        /// <summary>
        /// 验证文件是否真实有效 | 定时任务调用
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        BaseResult<bool> CheckFileIsVailded(CheckFileIsVaildedReq req);

        /// <summary>
        /// 根据附件id下载附件
        /// </summary>
        /// <param name="Id">附件id</param>
        /// <returns></returns>
        (byte[], string) DownloadFileByAnnexId(long Id);
    }
}