﻿using BPA.Component.ApolloClient;
using BPA.Component.MongoClient;
using Com.Ctrip.Framework.Apollo;
using Microsoft.Extensions.Configuration;

namespace BPA.SaaS.Annex.Api.Model
{
    /// <summary>
    /// 全局配置
    /// </summary>
    public class AnnexApiConfig : ApolloBPAConfig<AnnexApiConfig>
    {
        /// <summary>
        /// MongoDB [附件] 库群
        /// </summary>
        [AutoWrite]
        public List<MongoConfig> MongoDBAnnexs { get; protected set; }

        /// <summary>
        /// 腾讯Cos AppId 
        /// </summary>
        [AutoWrite]
        public string TencentCosAppId { protected set; get; }

        /// <summary>
        /// 腾讯Cos secretId
        /// </summary>
        [AutoWrite]
        public string TencentCosSecretId { protected set; get; }

        /// <summary>
        /// 腾讯Cos secretKey
        /// </summary>
        [AutoWrite]
        public string TencentCosSecretKey { protected set; get; }

        /// <summary>
        /// 腾讯Cos bucket
        /// </summary>
        [AutoWrite]
        public string TencentCosBucket { protected set; get; }

        /// <summary>
        /// 腾讯Cos region
        /// </summary>
        [AutoWrite]
        public string TencentCosRegion { protected set; get; }

        /// <summary>
        /// 腾讯Cos 每次请求签名有效时长，单位为秒
        /// </summary>
        public long TencentCosDurationSecond { protected set; get; } = 600;

        /// <summary>
        /// 文档文件扩展名集合
        /// </summary>
        [AutoWrite]
        public List<string> DocFileExtensions { get; protected set; } = new();

        /// <summary>
        /// 压缩文件扩展名集合
        /// </summary>
        [AutoWrite]
        public List<string> CompressFieldExtensions { get; protected set; } = new();

        /// <summary>
        /// 图片文件扩展名集合
        /// </summary>
        [AutoWrite]
        public List<string> ImageFieldExtensions { get; protected set; } = new();

        /// <summary>
        /// 视频文件扩展名集合
        /// </summary>
        [AutoWrite]
        public List<string> VideoFileExtensions { get; protected set; } = new();

        /// <summary>
        /// 音频文件扩展名集合
        /// </summary>
        [AutoWrite]
        public List<string> AudioFileExtensions { get; protected set; } = new();

        /// <summary>
        /// 附件url加密key
        /// </summary>
        [AutoWrite]
        public string SignKey { get; set; }

        /// <summary>
        /// 附件下载地址
        /// </summary>
        [AutoWrite]
        public string DownloadUrl { get; set; }

        /// <summary>
        /// 预览地址
        /// </summary>
        [AutoWrite]
        public string PreviewUrl { get; set; }

        /// <summary>
        /// 浏览器可预览的附件类型
        /// </summary>
        [AutoWrite]
        public List<string> PreviewInBrowserFile { get; set; }

        /// <summary>
        /// CRMBasicApiConfig
        /// </summary>
        /// <param name="apolloConfigurationManager"></param>
        /// <param name="configuration"></param>
        public AnnexApiConfig(ApolloConfigurationManager apolloConfigurationManager, IConfiguration configuration)
            : base(apolloConfigurationManager, configuration)
        {
        }
    }
}