﻿using BPA.Common.Enums.Annex;
using BPA.Component.DTOCommon.BaseDTOs;
using BPA.Component.Extensions;
using BPA.SaaS.Annex.Api.DTO;
using BPA.SaaS.Annex.Api.IRepository;
using BPA.SaaS.Annex.Api.IService;
using BPA.SaaS.Annex.Api.Model;
using BPA.SaaS.Basic.Api.SDK;
using COSXML;
using Microsoft.Extensions.Logging;

namespace BPA.SaaS.Annex.Api.Service;

/// <summary>
/// 附件服务
/// </summary>
public class CorpAnnexService : IAnnexService
{
    private readonly ILogger<CorpAnnexService> _logger;
    private readonly AnnexApiLangPackage _langPackage;
    private readonly Lazy<CosXml> _cosXml;
    private readonly AnnexApiConfig _annexApiConfig;
    private readonly Lazy<IAnnexRepository> _annexRepository;
    private readonly Lazy<BasicWebApiSDK> _basicWebApiSDK;

    public CorpAnnexService(ILogger<CorpAnnexService> logger,
        AnnexApiLangPackage langPackage,
        AnnexApiConfig annexApiConfig,
        Lazy<CosXml> cosXml,
        Lazy<IAnnexRepository> annexRepository,
        Lazy<BasicWebApiSDK> basicWebApiSDK)
    {
        _logger = logger;
        _langPackage = langPackage;
        _cosXml = cosXml;
        _annexApiConfig = annexApiConfig;
        _annexRepository = annexRepository;
        _basicWebApiSDK = basicWebApiSDK;
    }

    public BaseResult<List<AnnexInfoDTO>> GetList(GetListReq req)
    {
        var result = _annexRepository.Value.Queryable()
            .Where(a => a.BusinessType == req.BusinessType && a.BusinessId == req.BusinessId)
            .Select(a => new AnnexInfoDTO
            {
                BusinessId = a.BusinessId,
                BusinessType = a.BusinessType,
                CreateDate = a.CreateDate,
                CreatorName = a.Creator.Name,
                CreatorWeChatId = a.Creator.WeChatId,
                FileExtName = a.FileExtName,
                FileName = a.FileName,
                FileSize = a.FileSize,
                FileType = a.FileType,
                Id = a.Id,
            }).ToList();

        throw new NotImplementedException();
    }

    public BaseResult<bool> RemoveAnnexByBusinessId(RemoveAnnexByBusinessIdReq req)
    {
        throw new NotImplementedException();
    }

    public BaseResult<bool> RemoveAnnexByAnnexId(RemoveAnnexByAnnexIdReq req)
    {
        throw new NotImplementedException();
    }

    public BaseResult<bool> Upload(UploadAnnexReq req)
    {
        throw new NotImplementedException();
    }

    public BaseResult<AnnexInfoDTO> GetAnnexInfo(GetAnnexInfoReq req)
    {
        throw new NotImplementedException();
    }

    public BaseResult<bool> ClearTemporaryFile()
    {
        throw new NotImplementedException();
    }

    public BaseResult<bool> CheckFileIsVailded(CheckFileIsVaildedReq req)
    {
        throw new NotImplementedException();
    }

    public (byte[], string) DownloadFileByAnnexId(long Id)
    {
        throw new NotImplementedException();
    }

    #region private

    /// <summary>
    /// 获取文件类型
    /// </summary>
    /// <param name="extension"></param>
    /// <returns></returns>
    private EnumAnnexType GetAnnexType(string extension)
    {
        extension = extension.ToLower();

        if (_annexApiConfig.DocFileExtensions.Contains(extension))
            return EnumAnnexType.Doc;
        if (_annexApiConfig.AudioFileExtensions.Contains(extension))
            return EnumAnnexType.Audio;
        if (_annexApiConfig.VideoFileExtensions.Contains(extension))
            return EnumAnnexType.Video;
        if (_annexApiConfig.ImageFieldExtensions.Contains(extension))
            return EnumAnnexType.Image;

        return _annexApiConfig.CompressFieldExtensions.Contains(extension)
            ? EnumAnnexType.Compress
            : EnumAnnexType.Unknow;
    }

    /// <summary>
    /// 处理文件容量大小的字符串
    /// </summary>
    /// <param name="fileSize"></param>
    /// <returns></returns>
    private string GetFileSizeChar(long fileSize)
    {
        var size = (double) fileSize / 1024;

        if (size < 1024) return Math.Round(size, 2) + "KB";

        size /= 1024;
        if (size < 1024) return Math.Round(size, 2) + "MB";

        size /= 1024;
        return Math.Round(size, 2) + "GB";
    }

    /// <summary>
    /// 附件url签名
    /// </summary>
    /// <returns></returns>
    private string Sign(AnnexInfoDTO annexInfo, long corpId, long? timespan)
    {
        return $"{corpId.ToHex()}{annexInfo.Id.ToHex()}{annexInfo.FileExtName}{timespan}{_annexApiConfig.SignKey}".Md5();
    }

    /// <summary>
    ///  附件url签名
    /// </summary>
    /// <returns></returns>
    private string Sign(string annexId, string corpIdHex, string timespan)
    {
        return $"{corpIdHex}{annexId}{timespan}{_annexApiConfig.SignKey}".Md5();
    }

    #endregion
}